@@ -110,6 +110,16 @@ class Win32Utils(object):
         kernel32.SetLastError(0)
         return error_code
 
+    @staticmethod
+    def hresult_to_err_code(hresult):
+        # The last 2 bytes of the hresult store the error code.
+        return hresult & 0xFFFF
+
+    def get_com_err_code(self, com_error):
+        hres = _utils.get_com_error_hresult(com_error)
+        if hres is not None:
+            return self.hresult_to_err_code(hres)
+
     def local_free(self, handle):
         try:
             self._run_and_check_output(kernel32.LocalFree, handle)
@@ -135,3 +145,16 @@ class Win32Utils(object):
             raise exceptions.Timeout()
 
         return ret_val
+
+    def wait_for_single_object(self, handle,
+                               milliseconds=w_const.INFINITE):
+        ret_val = self.run_and_check_output(
+            kernel32.WaitForSingleObject,
+            handle,
+            milliseconds,
+            kernel32_lib_func=True,
+            error_ret_vals=[w_const.WAIT_FAILED])
+        if ret_val == w_const.ERROR_WAIT_TIMEOUT:
+            raise exceptions.Timeout()
+
+        return ret_val
